flownetpy package
=================

Subpackages
-----------

.. toctree::

    flownetpy.flowmodel
    flownetpy.tests

Module contents
---------------

.. automodule:: flownetpy
    :members:
    :undoc-members:
    :show-inheritance:
